@@ -4,12 +4,12 @@ from re import search
 from bson.objectid import ObjectId
 from jsonclasses.jfield import JField
 from pymongo.errors import DuplicateKeyError
-from inflection import camelize, underscore
 from pymongo.collection import Collection
 from pymongo import ASCENDING
 from jsonclasses.fdef import FStore, FType
 from jsonclasses.excs import UniqueConstraintException
 from jsonclasses.excs import DeletionDeniedException
+from inflection import underscore, camelize
 from .pymongo_object import PymongoObject
 from .query import BaseQuery, ExistQuery, IterateQuery, ListQuery, SingleQuery, IDQuery
 from .encoder import Encoder
