@@ -11,7 +11,10 @@ from tests.classes.chained_user import (
     ChainedAddress, ChainedProfile, ChainedUser
 )
 from tests.classes.linked_song import LinkedSong, LinkedSinger
-
+from tests.classes.linked_todo_list import TodoListOwner, TodoList
+from tests.classes.linked_pop_singer import PopSinger, PopSong
+from tests.classes.linked_hiphop_song import HiphopSinger, HiphopSong
+from tests.classes.linked_music_product import MusicProduct, MusicUser
 
 
 class TestSave(TestCase):
@@ -67,6 +70,22 @@ class TestSave(TestCase):
         collection.delete_many({})
         collection = Connection.get_collection(LinkedSinger)
         collection.delete_many({})
+        collection = Connection.get_collection(TodoList)
+        collection.delete_many({})
+        collection = Connection.get_collection(TodoListOwner)
+        collection.delete_many({})
+        collection = Connection.get_collection(PopSong)
+        collection.delete_many({})
+        collection = Connection.get_collection(PopSinger)
+        collection.delete_many({})
+        collection = Connection.get_collection(HiphopSong)
+        collection.delete_many({})
+        collection = Connection.get_collection(HiphopSinger)
+        collection.delete_many({})
+        collection = Connection.get_collection(MusicProduct)
+        collection.delete_many({})
+        collection = Connection.get_collection(MusicUser)
+        collection.delete_many({})
 
     def test_1f_1l_ref_lookup_fetches_linked_object(self):
         user = LinkedUser(name='Teo Yeo')
@@ -470,3 +489,90 @@ class TestSave(TestCase):
         result = LinkedSong.one(name='Lu Bo To Teo Yeo').include('singers', LinkedSinger.find(name={'_suffix': 'Q'}).order('name', 1)).exec()
         self.assertEqual([singer.name for singer in result.singers], ['BQ', 'AQ'])
         self.assertEqual(len(result.singers), 2)
+
+    def test_multiwords_name_are_included_for_1l_manyf_on_manyf(self):
+        owner = TodoListOwner()
+        tl1 = TodoList(name='1', todo_list_owner=owner)
+        tl2 = TodoList(name='2', todo_list_owner=owner)
+        tl3 = TodoList(name='3', todo_list_owner=owner)
+        tl4 = TodoList(name='4', todo_list_owner=owner)
+        owner.save()
+        result = TodoListOwner.one({'_includes': ['todo_lists']}).exec()
+        self.assertEqual(len(result.todo_lists), 4)
+        result = TodoListOwner.one({'_includes': ['todoLists']}).exec()
+        self.assertEqual(len(result.todo_lists), 4)
+        result = TodoListOwner.one().include('todoLists').exec()
+        self.assertEqual(len(result.todo_lists), 4)
+        result = TodoListOwner.one().include('todo_lists').exec()
+        self.assertEqual(len(result.todo_lists), 4)
+
+    def test_multiwords_name_are_included_for_1l_manyf_on_1l(self):
+        owner = TodoListOwner()
+        tl1 = TodoList(name='1', todo_list_owner=owner)
+        tl2 = TodoList(name='2', todo_list_owner=owner)
+        tl3 = TodoList(name='3', todo_list_owner=owner)
+        tl4 = TodoList(name='4', todo_list_owner=owner)
+        owner.save()
+        result = TodoList.one({'_includes': ['todo_list_owner']}).exec()
+        self.assertIsNotNone(result.todo_list_owner)
+        result = TodoList.one({'_includes': ['todoListOwner']}).exec()
+        self.assertIsNotNone(result.todo_list_owner)
+        result = TodoList.one().include('todo_list_owner').exec()
+        self.assertIsNotNone(result.todo_list_owner)
+        result = TodoList.one().include('todoListOwner').exec()
+        self.assertIsNotNone(result.todo_list_owner)
+
+    def test_multiwords_name_are_included_for_1f_1l_on_1l(self):
+        PopSinger(pop_song=PopSong(name='song')).save()
+        result = PopSong.one({'_includes': ['pop_singer']}).exec()
+        self.assertIsNotNone(result.pop_singer)
+        result = PopSong.one({'_includes': ['popSinger']}).exec()
+        self.assertIsNotNone(result.pop_singer)
+        result = PopSong.one().include('pop_singer').exec()
+        self.assertIsNotNone(result.pop_singer)
+        result = PopSong.one().include('popSinger').exec()
+        self.assertIsNotNone(result.pop_singer)
+
+    def test_multiwords_name_are_included_for_1f_1l_on_1f(self):
+        PopSinger(pop_song=PopSong(name='song')).save()
+        result = PopSinger.one({'_includes': ['pop_song']}).exec()
+        self.assertIsNotNone(result.pop_song)
+        result = PopSinger.one({'_includes': ['popSong']}).exec()
+        self.assertIsNotNone(result.pop_song)
+        result = PopSinger.one().include('pop_song').exec()
+        self.assertIsNotNone(result.pop_song)
+        result = PopSinger.one().include('popSong').exec()
+        self.assertIsNotNone(result.pop_song)
+
+    def test_multiwords_name_are_included_for_manyf_manyl_on_manyl(self):
+        HiphopSinger(hiphop_songs=[HiphopSong(name='song')]).save()
+        result = HiphopSong.one({'_includes': ['hiphop_singers']}).exec()
+        self.assertEqual(len(result.hiphop_singers), 1)
+        result = HiphopSong.one({'_includes': ['hiphopSingers']}).exec()
+        self.assertEqual(len(result.hiphop_singers), 1)
+        result = HiphopSong.one().include('hiphop_singers').exec()
+        self.assertEqual(len(result.hiphop_singers), 1)
+        result = HiphopSong.one().include('hiphopSingers').exec()
+        self.assertEqual(len(result.hiphop_singers), 1)
+
+    def test_multiwords_name_are_included_for_manyf_manyl_on_manyf(self):
+        HiphopSinger(hiphop_songs=[HiphopSong(name='song')]).save()
+        result = HiphopSinger.one({'_includes': ['hiphop_songs']}).exec()
+        self.assertEqual(len(result.hiphop_songs), 1)
+        result = HiphopSinger.one({'_includes': ['hiphopSongs']}).exec()
+        self.assertEqual(len(result.hiphop_songs), 1)
+        result = HiphopSinger.one().include('hiphop_songs').exec()
+        self.assertEqual(len(result.hiphop_songs), 1)
+        result = HiphopSinger.one().include('hiphopSongs').exec()
+        self.assertEqual(len(result.hiphop_songs), 1)
+
+    def test_multiwords_name_are_included_for_many_ff(self):
+        MusicProduct(music_users=[MusicUser(name='song')]).save()
+        result = MusicProduct.one({'_includes': ['music_users']}).exec()
+        self.assertEqual(len(result.music_users), 1)
+        result = MusicProduct.one({'_includes': ['musicUsers']}).exec()
+        self.assertEqual(len(result.music_users), 1)
+        result = MusicProduct.one().include('music_users').exec()
+        self.assertEqual(len(result.music_users), 1)
+        result = MusicProduct.one().include('musicUsers').exec()
+        self.assertEqual(len(result.music_users), 1)
